| Copyright | (c) 2013-2016 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay <brendan.g.hay@gmail.com> |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | None |
| Language | Haskell2010 |
Network.AWS.SSM.Types
Contents
- Service Configuration
- Errors
- AssociationFilterKey
- AssociationStatusName
- CommandFilterKey
- CommandInvocationStatus
- CommandPluginStatus
- CommandStatus
- DescribeActivationsFilterKeys
- DocumentFilterKey
- DocumentHashType
- DocumentParameterType
- DocumentPermissionType
- DocumentStatus
- Fault
- InstanceInformationFilterKey
- NotificationEvent
- NotificationType
- PingStatus
- PlatformType
- ResourceType
- ResourceTypeForTagging
- Activation
- Association
- AssociationDescription
- AssociationFilter
- AssociationStatus
- Command
- CommandFilter
- CommandInvocation
- CommandPlugin
- CreateAssociationBatchRequestEntry
- DescribeActivationsFilter
- DocumentDescription
- DocumentFilter
- DocumentIdentifier
- DocumentParameter
- FailedCreateAssociation
- InstanceInformation
- InstanceInformationFilter
- NotificationConfig
- Tag
Description
- ssm :: Service
- _UnsupportedPlatformType :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidPermissionType :: AsError a => Getting (First ServiceError) a ServiceError
- _AssociatedInstances :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidInstanceId :: AsError a => Getting (First ServiceError) a ServiceError
- _StatusUnchanged :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidNextToken :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidOutputFolder :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidActivationId :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidCommandId :: AsError a => Getting (First ServiceError) a ServiceError
- _DuplicateInstanceId :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidResourceType :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidDocument :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidFilterKey :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidInstanceInformationFilterValue :: AsError a => Getting (First ServiceError) a ServiceError
- _AssociationAlreadyExists :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidDocumentContent :: AsError a => Getting (First ServiceError) a ServiceError
- _AssociationLimitExceeded :: AsError a => Getting (First ServiceError) a ServiceError
- _AssociationDoesNotExist :: AsError a => Getting (First ServiceError) a ServiceError
- _InternalServerError :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidRole :: AsError a => Getting (First ServiceError) a ServiceError
- _TooManyUpdates :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidActivation :: AsError a => Getting (First ServiceError) a ServiceError
- _MaxDocumentSizeExceeded :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidDocumentOperation :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidParameters :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidResourceId :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidNotificationConfig :: AsError a => Getting (First ServiceError) a ServiceError
- _DocumentPermissionLimit :: AsError a => Getting (First ServiceError) a ServiceError
- _DocumentAlreadyExists :: AsError a => Getting (First ServiceError) a ServiceError
- _DocumentLimitExceeded :: AsError a => Getting (First ServiceError) a ServiceError
- _InvalidFilter :: AsError a => Getting (First ServiceError) a ServiceError
- data AssociationFilterKey
- data AssociationStatusName
- data CommandFilterKey
- data CommandInvocationStatus
- data CommandPluginStatus
- data CommandStatus
- data DescribeActivationsFilterKeys
- data DocumentFilterKey
- = Name
- | Owner
- | PlatformTypes
- data DocumentHashType
- data DocumentParameterType
- = String
- | StringList
- data DocumentPermissionType = Share
- data DocumentStatus
- data Fault
- data InstanceInformationFilterKey
- data NotificationEvent
- data NotificationType
- data PingStatus
- data PlatformType
- data ResourceType
- data ResourceTypeForTagging = RTFTManagedInstance
- data Activation
- activation :: Activation
- aExpired :: Lens' Activation (Maybe Bool)
- aDefaultInstanceName :: Lens' Activation (Maybe Text)
- aActivationId :: Lens' Activation (Maybe Text)
- aCreatedDate :: Lens' Activation (Maybe UTCTime)
- aRegistrationLimit :: Lens' Activation (Maybe Natural)
- aExpirationDate :: Lens' Activation (Maybe UTCTime)
- aDescription :: Lens' Activation (Maybe Text)
- aRegistrationsCount :: Lens' Activation (Maybe Natural)
- aIAMRole :: Lens' Activation (Maybe Text)
- data Association
- association :: Association
- aInstanceId :: Lens' Association (Maybe Text)
- aName :: Lens' Association (Maybe Text)
- data AssociationDescription
- associationDescription :: AssociationDescription
- adInstanceId :: Lens' AssociationDescription (Maybe Text)
- adStatus :: Lens' AssociationDescription (Maybe AssociationStatus)
- adDate :: Lens' AssociationDescription (Maybe UTCTime)
- adName :: Lens' AssociationDescription (Maybe Text)
- adParameters :: Lens' AssociationDescription (HashMap Text [Text])
- data AssociationFilter
- associationFilter :: AssociationFilterKey -> Text -> AssociationFilter
- afKey :: Lens' AssociationFilter AssociationFilterKey
- afValue :: Lens' AssociationFilter Text
- data AssociationStatus
- associationStatus :: UTCTime -> AssociationStatusName -> Text -> AssociationStatus
- asAdditionalInfo :: Lens' AssociationStatus (Maybe Text)
- asDate :: Lens' AssociationStatus UTCTime
- asName :: Lens' AssociationStatus AssociationStatusName
- asMessage :: Lens' AssociationStatus Text
- data Command
- command :: Command
- cStatus :: Lens' Command (Maybe CommandStatus)
- cExpiresAfter :: Lens' Command (Maybe UTCTime)
- cNotificationConfig :: Lens' Command (Maybe NotificationConfig)
- cOutputS3KeyPrefix :: Lens' Command (Maybe Text)
- cDocumentName :: Lens' Command (Maybe Text)
- cInstanceIds :: Lens' Command (Maybe (NonEmpty Text))
- cCommandId :: Lens' Command (Maybe Text)
- cParameters :: Lens' Command (HashMap Text [Text])
- cComment :: Lens' Command (Maybe Text)
- cOutputS3BucketName :: Lens' Command (Maybe Text)
- cRequestedDateTime :: Lens' Command (Maybe UTCTime)
- cServiceRole :: Lens' Command (Maybe Text)
- data CommandFilter
- commandFilter :: CommandFilterKey -> Text -> CommandFilter
- cfKey :: Lens' CommandFilter CommandFilterKey
- cfValue :: Lens' CommandFilter Text
- data CommandInvocation
- commandInvocation :: CommandInvocation
- ciInstanceId :: Lens' CommandInvocation (Maybe Text)
- ciStatus :: Lens' CommandInvocation (Maybe CommandInvocationStatus)
- ciNotificationConfig :: Lens' CommandInvocation (Maybe NotificationConfig)
- ciCommandPlugins :: Lens' CommandInvocation [CommandPlugin]
- ciDocumentName :: Lens' CommandInvocation (Maybe Text)
- ciCommandId :: Lens' CommandInvocation (Maybe Text)
- ciComment :: Lens' CommandInvocation (Maybe Text)
- ciTraceOutput :: Lens' CommandInvocation (Maybe Text)
- ciRequestedDateTime :: Lens' CommandInvocation (Maybe UTCTime)
- ciServiceRole :: Lens' CommandInvocation (Maybe Text)
- data CommandPlugin
- commandPlugin :: CommandPlugin
- cpStatus :: Lens' CommandPlugin (Maybe CommandPluginStatus)
- cpResponseStartDateTime :: Lens' CommandPlugin (Maybe UTCTime)
- cpOutputS3KeyPrefix :: Lens' CommandPlugin (Maybe Text)
- cpResponseCode :: Lens' CommandPlugin (Maybe Int)
- cpOutput :: Lens' CommandPlugin (Maybe Text)
- cpName :: Lens' CommandPlugin (Maybe Text)
- cpOutputS3BucketName :: Lens' CommandPlugin (Maybe Text)
- cpResponseFinishDateTime :: Lens' CommandPlugin (Maybe UTCTime)
- data CreateAssociationBatchRequestEntry
- createAssociationBatchRequestEntry :: CreateAssociationBatchRequestEntry
- cabreInstanceId :: Lens' CreateAssociationBatchRequestEntry (Maybe Text)
- cabreName :: Lens' CreateAssociationBatchRequestEntry (Maybe Text)
- cabreParameters :: Lens' CreateAssociationBatchRequestEntry (HashMap Text [Text])
- data DescribeActivationsFilter
- describeActivationsFilter :: DescribeActivationsFilter
- dafFilterKey :: Lens' DescribeActivationsFilter (Maybe DescribeActivationsFilterKeys)
- dafFilterValues :: Lens' DescribeActivationsFilter [Text]
- data DocumentDescription
- documentDescription :: DocumentDescription
- dStatus :: Lens' DocumentDescription (Maybe DocumentStatus)
- dHash :: Lens' DocumentDescription (Maybe Text)
- dSha1 :: Lens' DocumentDescription (Maybe Text)
- dOwner :: Lens' DocumentDescription (Maybe Text)
- dPlatformTypes :: Lens' DocumentDescription [PlatformType]
- dCreatedDate :: Lens' DocumentDescription (Maybe UTCTime)
- dName :: Lens' DocumentDescription (Maybe Text)
- dHashType :: Lens' DocumentDescription (Maybe DocumentHashType)
- dParameters :: Lens' DocumentDescription [DocumentParameter]
- dDescription :: Lens' DocumentDescription (Maybe Text)
- data DocumentFilter
- documentFilter :: DocumentFilterKey -> Text -> DocumentFilter
- dfKey :: Lens' DocumentFilter DocumentFilterKey
- dfValue :: Lens' DocumentFilter Text
- data DocumentIdentifier
- documentIdentifier :: DocumentIdentifier
- diOwner :: Lens' DocumentIdentifier (Maybe Text)
- diPlatformTypes :: Lens' DocumentIdentifier [PlatformType]
- diName :: Lens' DocumentIdentifier (Maybe Text)
- data DocumentParameter
- documentParameter :: DocumentParameter
- dpName :: Lens' DocumentParameter (Maybe Text)
- dpDefaultValue :: Lens' DocumentParameter (Maybe Text)
- dpType :: Lens' DocumentParameter (Maybe DocumentParameterType)
- dpDescription :: Lens' DocumentParameter (Maybe Text)
- data FailedCreateAssociation
- failedCreateAssociation :: FailedCreateAssociation
- fcaEntry :: Lens' FailedCreateAssociation (Maybe CreateAssociationBatchRequestEntry)
- fcaFault :: Lens' FailedCreateAssociation (Maybe Fault)
- fcaMessage :: Lens' FailedCreateAssociation (Maybe Text)
- data InstanceInformation
- instanceInformation :: InstanceInformation
- iiInstanceId :: Lens' InstanceInformation (Maybe Text)
- iiPingStatus :: Lens' InstanceInformation (Maybe PingStatus)
- iiIPAddress :: Lens' InstanceInformation (Maybe Text)
- iiResourceType :: Lens' InstanceInformation (Maybe ResourceType)
- iiRegistrationDate :: Lens' InstanceInformation (Maybe UTCTime)
- iiPlatformVersion :: Lens' InstanceInformation (Maybe Text)
- iiIsLatestVersion :: Lens' InstanceInformation (Maybe Bool)
- iiAgentVersion :: Lens' InstanceInformation (Maybe Text)
- iiLastPingDateTime :: Lens' InstanceInformation (Maybe UTCTime)
- iiActivationId :: Lens' InstanceInformation (Maybe Text)
- iiName :: Lens' InstanceInformation (Maybe Text)
- iiPlatformType :: Lens' InstanceInformation (Maybe PlatformType)
- iiPlatformName :: Lens' InstanceInformation (Maybe Text)
- iiComputerName :: Lens' InstanceInformation (Maybe Text)
- iiIAMRole :: Lens' InstanceInformation (Maybe Text)
- data InstanceInformationFilter
- instanceInformationFilter :: InstanceInformationFilterKey -> NonEmpty Text -> InstanceInformationFilter
- iifKey :: Lens' InstanceInformationFilter InstanceInformationFilterKey
- iifValueSet :: Lens' InstanceInformationFilter (NonEmpty Text)
- data NotificationConfig
- notificationConfig :: NotificationConfig
- ncNotificationEvents :: Lens' NotificationConfig [NotificationEvent]
- ncNotificationType :: Lens' NotificationConfig (Maybe NotificationType)
- ncNotificationARN :: Lens' NotificationConfig (Maybe Text)
- data Tag
- tag :: Text -> Text -> Tag
- tagKey :: Lens' Tag Text
- tagValue :: Lens' Tag Text
Service Configuration
API version '2014-11-06' of the Amazon Simple Systems Management Service SDK configuration.
Errors
_UnsupportedPlatformType :: AsError a => Getting (First ServiceError) a ServiceError Source #
The document does not support the platform type of the given instance ID(s). For example, you sent an SSM document for a Windows instance to a Linux instance.
_InvalidPermissionType :: AsError a => Getting (First ServiceError) a ServiceError Source #
The permission type is not supported. Share is the only supported permission type.
_AssociatedInstances :: AsError a => Getting (First ServiceError) a ServiceError Source #
You must disassociate an SSM document from all instances before you can delete it.
_InvalidInstanceId :: AsError a => Getting (First ServiceError) a ServiceError Source #
The instance is not in valid state. Valid states are: Running, Pending, Stopped, Stopping. Invalid states are: Shutting-down and Terminated.
_StatusUnchanged :: AsError a => Getting (First ServiceError) a ServiceError Source #
The updated status is the same as the current status.
_InvalidNextToken :: AsError a => Getting (First ServiceError) a ServiceError Source #
The specified token is not valid.
_InvalidOutputFolder :: AsError a => Getting (First ServiceError) a ServiceError Source #
The S3 bucket does not exist.
_InvalidActivationId :: AsError a => Getting (First ServiceError) a ServiceError Source #
The activation ID is not valid. Verify the you entered the correct ActivationId or ActivationCode and try again.
_InvalidCommandId :: AsError a => Getting (First ServiceError) a ServiceError Source #
Prism for InvalidCommandId' errors.
_DuplicateInstanceId :: AsError a => Getting (First ServiceError) a ServiceError Source #
You cannot specify an instance ID in more than one association.
_InvalidResourceType :: AsError a => Getting (First ServiceError) a ServiceError Source #
The resource type is not valid. If you are attempting to tag an instance, the instance must be a registered, managed instance.
_InvalidDocument :: AsError a => Getting (First ServiceError) a ServiceError Source #
The specified document does not exist.
_InvalidFilterKey :: AsError a => Getting (First ServiceError) a ServiceError Source #
The specified key is not valid.
_InvalidInstanceInformationFilterValue :: AsError a => Getting (First ServiceError) a ServiceError Source #
The specified filter value is not valid.
_AssociationAlreadyExists :: AsError a => Getting (First ServiceError) a ServiceError Source #
The specified association already exists.
_InvalidDocumentContent :: AsError a => Getting (First ServiceError) a ServiceError Source #
The content for the SSM document is not valid.
_AssociationLimitExceeded :: AsError a => Getting (First ServiceError) a ServiceError Source #
You can have at most 2,000 active associations.
_AssociationDoesNotExist :: AsError a => Getting (First ServiceError) a ServiceError Source #
The specified association does not exist.
_InternalServerError :: AsError a => Getting (First ServiceError) a ServiceError Source #
An error occurred on the server side.
_InvalidRole :: AsError a => Getting (First ServiceError) a ServiceError Source #
The role name can't contain invalid characters. Also verify that you specified an IAM role for notifications that includes the required trust policy. For information about configuring the IAM role for SSM notifications, see Configuring SNS Notifications SSM in the Amazon Elastic Compute Cloud User Guide .
_TooManyUpdates :: AsError a => Getting (First ServiceError) a ServiceError Source #
There are concurrent updates for a resource that supports one update at a time.
_InvalidActivation :: AsError a => Getting (First ServiceError) a ServiceError Source #
The activation is not valid. The activation might have been deleted, or the ActivationId and the ActivationCode do not match.
_MaxDocumentSizeExceeded :: AsError a => Getting (First ServiceError) a ServiceError Source #
The size limit of an SSM document is 64 KB.
_InvalidDocumentOperation :: AsError a => Getting (First ServiceError) a ServiceError Source #
You attempted to delete a document while it is still shared. You must stop sharing the document before you can delete it.
_InvalidParameters :: AsError a => Getting (First ServiceError) a ServiceError Source #
You must specify values for all required parameters in the SSM document. You can only supply values to parameters defined in the SSM document.
_InvalidResourceId :: AsError a => Getting (First ServiceError) a ServiceError Source #
The resource ID is not valid. Verify that you entered the correct ID and try again.
_InvalidNotificationConfig :: AsError a => Getting (First ServiceError) a ServiceError Source #
One or more configuration items is not valid. Verify that a valid Amazon Resource Name (ARN) was provided for an Amazon SNS topic.
_DocumentPermissionLimit :: AsError a => Getting (First ServiceError) a ServiceError Source #
The document cannot be shared with more AWS user accounts. You can share a document with a maximum of 20 accounts. You can publicly share up to five documents. If you need to increase this limit, contact AWS Support.
_DocumentAlreadyExists :: AsError a => Getting (First ServiceError) a ServiceError Source #
The specified SSM document already exists.
_DocumentLimitExceeded :: AsError a => Getting (First ServiceError) a ServiceError Source #
You can have at most 200 active SSM documents.
_InvalidFilter :: AsError a => Getting (First ServiceError) a ServiceError Source #
The filter name is not valid. Verify the you entered the correct name and try again.
AssociationFilterKey
data AssociationFilterKey Source #
Constructors
| AFKInstanceId | |
| AFKName |
Instances
AssociationStatusName
data AssociationStatusName Source #
Constructors
| ASNFailed | |
| ASNPending | |
| ASNSuccess |
Instances
CommandFilterKey
data CommandFilterKey Source #
Constructors
| CommandInvokedAfter | |
| CommandInvokedBefore | |
| CommandStatus |
Instances
CommandInvocationStatus
data CommandInvocationStatus Source #
Instances
CommandPluginStatus
data CommandPluginStatus Source #
Constructors
| CPSCancelled | |
| CPSFailed | |
| CPSInProgress | |
| CPSPending | |
| CPSSuccess | |
| CPSTimedOut |
Instances
CommandStatus
data CommandStatus Source #
Constructors
| Cancelled | |
| Cancelling | |
| Failed | |
| InProgress | |
| Pending | |
| Success | |
| TimedOut |
Instances
DescribeActivationsFilterKeys
data DescribeActivationsFilterKeys Source #
Constructors
| ActivationIds | |
| DefaultInstanceName | |
| IAMRole |
Instances
DocumentFilterKey
data DocumentFilterKey Source #
Constructors
| Name | |
| Owner | |
| PlatformTypes |
Instances
DocumentHashType
data DocumentHashType Source #
Constructors
| HashSHA1 | |
| HashSHA256 |
Instances
DocumentParameterType
data DocumentParameterType Source #
Constructors
| String | |
| StringList |
Instances
DocumentPermissionType
data DocumentPermissionType Source #
Constructors
| Share |
Instances
DocumentStatus
data DocumentStatus Source #
Instances
Fault
Instances
InstanceInformationFilterKey
data InstanceInformationFilterKey Source #
Constructors
| IIFKActivationIds | |
| IIFKAgentVersion | |
| IIFKIAMRole | |
| IIFKInstanceIds | |
| IIFKPingStatus | |
| IIFKPlatformTypes | |
| IIFKResourceType |
Instances
NotificationEvent
data NotificationEvent Source #
Constructors
| NEAll | |
| NECancelled | |
| NEFailed | |
| NEInProgress | |
| NESuccess | |
| NETimedOut |
Instances
NotificationType
data NotificationType Source #
Constructors
| Command | |
| Invocation |
Instances
PingStatus
data PingStatus Source #
Constructors
| ConnectionLost | |
| Inactive | |
| Online |
Instances
PlatformType
data PlatformType Source #
Instances
ResourceType
data ResourceType Source #
Constructors
| Document | |
| EC2Instance | |
| ManagedInstance |
Instances
ResourceTypeForTagging
data ResourceTypeForTagging Source #
Constructors
| RTFTManagedInstance |
Instances
Activation
data Activation Source #
An activation registers one or more on-premises servers or virtual machines (VMs) with AWS so that you can configure those servers or VMs using Run Command. A server or VM that has been registered with AWS is called a managed instance.
See: activation smart constructor.
Instances
activation :: Activation Source #
Creates a value of Activation with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
aDefaultInstanceName :: Lens' Activation (Maybe Text) Source #
A name for the managed instance when it is created.
aActivationId :: Lens' Activation (Maybe Text) Source #
The ID created by SSM when you submitted the activation.
aCreatedDate :: Lens' Activation (Maybe UTCTime) Source #
The date the activation was created.
aRegistrationLimit :: Lens' Activation (Maybe Natural) Source #
The maximum number of managed instances that can be registered using this activation.
aExpirationDate :: Lens' Activation (Maybe UTCTime) Source #
The date when this activation can no longer be used to register managed instances.
aDescription :: Lens' Activation (Maybe Text) Source #
A user defined description of the activation.
aRegistrationsCount :: Lens' Activation (Maybe Natural) Source #
The number of managed instances already registered with this activation.
aIAMRole :: Lens' Activation (Maybe Text) Source #
The Amazon Identity and Access Management (IAM) role to assign to the managed instance.
Association
data Association Source #
Describes an association of an SSM document and an instance.
See: association smart constructor.
association :: Association Source #
Creates a value of Association with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
aInstanceId :: Lens' Association (Maybe Text) Source #
The ID of the instance.
AssociationDescription
data AssociationDescription Source #
Describes the parameters for a document.
See: associationDescription smart constructor.
Instances
associationDescription :: AssociationDescription Source #
Creates a value of AssociationDescription with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
adInstanceId :: Lens' AssociationDescription (Maybe Text) Source #
The ID of the instance.
adStatus :: Lens' AssociationDescription (Maybe AssociationStatus) Source #
The association status.
adDate :: Lens' AssociationDescription (Maybe UTCTime) Source #
The date when the association was made.
adParameters :: Lens' AssociationDescription (HashMap Text [Text]) Source #
A description of the parameters for a document.
AssociationFilter
data AssociationFilter Source #
Describes a filter.
See: associationFilter smart constructor.
Instances
Arguments
| :: AssociationFilterKey | |
| -> Text | |
| -> AssociationFilter |
Creates a value of AssociationFilter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
afKey :: Lens' AssociationFilter AssociationFilterKey Source #
The name of the filter.
AssociationStatus
data AssociationStatus Source #
Describes an association status.
See: associationStatus smart constructor.
Instances
Arguments
| :: UTCTime | |
| -> AssociationStatusName | |
| -> Text | |
| -> AssociationStatus |
Creates a value of AssociationStatus with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
asAdditionalInfo :: Lens' AssociationStatus (Maybe Text) Source #
A user-defined string.
asName :: Lens' AssociationStatus AssociationStatusName Source #
The status.
Command
Describes a command request.
See: command smart constructor.
Creates a value of Command with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cExpiresAfter :: Lens' Command (Maybe UTCTime) Source #
If this time is reached and the command has not already started executing, it will not execute. Calculated based on the ExpiresAfter user input provided as part of the SendCommand API.
cNotificationConfig :: Lens' Command (Maybe NotificationConfig) Source #
Configurations for sending notifications about command status changes.
cOutputS3KeyPrefix :: Lens' Command (Maybe Text) Source #
The S3 directory path inside the bucket where the responses to the command executions should be stored. This was requested when issuing the command.
cDocumentName :: Lens' Command (Maybe Text) Source #
The name of the SSM document requested for execution.
cInstanceIds :: Lens' Command (Maybe (NonEmpty Text)) Source #
The instance IDs against which this command was requested.
cParameters :: Lens' Command (HashMap Text [Text]) Source #
The parameter values to be inserted in the SSM document when executing the command.
cComment :: Lens' Command (Maybe Text) Source #
User-specified information about the command, such as a brief description of what the command should do.
cOutputS3BucketName :: Lens' Command (Maybe Text) Source #
The S3 bucket where the responses to the command executions should be stored. This was requested when issuing the command.
cRequestedDateTime :: Lens' Command (Maybe UTCTime) Source #
The date and time the command was requested.
cServiceRole :: Lens' Command (Maybe Text) Source #
The IAM service role that SSM uses to act on your behalf when sending notifications about command status changes.
CommandFilter
data CommandFilter Source #
Describes a command filter.
See: commandFilter smart constructor.
Arguments
| :: CommandFilterKey | |
| -> Text | |
| -> CommandFilter |
Creates a value of CommandFilter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cfKey :: Lens' CommandFilter CommandFilterKey Source #
The name of the filter. For example, requested date and time.
CommandInvocation
data CommandInvocation Source #
An invocation is copy of a command sent to a specific instance. A command can apply to one or more instances. A command invocation applies to one instance. For example, if a user executes SendCommand against three instances, then a command invocation is created for each requested instance ID. A command invocation returns status and detail information about a command you executed.
See: commandInvocation smart constructor.
Instances
commandInvocation :: CommandInvocation Source #
Creates a value of CommandInvocation with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ciInstanceId :: Lens' CommandInvocation (Maybe Text) Source #
The instance ID in which this invocation was requested.
ciStatus :: Lens' CommandInvocation (Maybe CommandInvocationStatus) Source #
Whether or not the invocation succeeded, failed, or is pending.
ciNotificationConfig :: Lens' CommandInvocation (Maybe NotificationConfig) Source #
Configurations for sending notifications about command status changes on a per instance basis.
ciCommandPlugins :: Lens' CommandInvocation [CommandPlugin] Source #
Undocumented member.
ciDocumentName :: Lens' CommandInvocation (Maybe Text) Source #
The document name that was requested for execution.
ciCommandId :: Lens' CommandInvocation (Maybe Text) Source #
The command against which this invocation was requested.
ciComment :: Lens' CommandInvocation (Maybe Text) Source #
User-specified information about the command, such as a brief description of what the command should do.
ciTraceOutput :: Lens' CommandInvocation (Maybe Text) Source #
Gets the trace output sent by the agent.
ciRequestedDateTime :: Lens' CommandInvocation (Maybe UTCTime) Source #
The time and date the request was sent to this instance.
ciServiceRole :: Lens' CommandInvocation (Maybe Text) Source #
The IAM service role that SSM uses to act on your behalf when sending notifications about command status changes on a per instance basis.
CommandPlugin
data CommandPlugin Source #
Describes plugin details.
See: commandPlugin smart constructor.
commandPlugin :: CommandPlugin Source #
Creates a value of CommandPlugin with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cpStatus :: Lens' CommandPlugin (Maybe CommandPluginStatus) Source #
The status of this plugin. You can execute a document with multiple plugins.
cpResponseStartDateTime :: Lens' CommandPlugin (Maybe UTCTime) Source #
The time the plugin started executing.
cpOutputS3KeyPrefix :: Lens' CommandPlugin (Maybe Text) Source #
The S3 directory path inside the bucket where the responses to the command executions should be stored. This was requested when issuing the command.
cpResponseCode :: Lens' CommandPlugin (Maybe Int) Source #
A numeric response code generated after executing the plugin.
cpName :: Lens' CommandPlugin (Maybe Text) Source #
The name of the plugin. Must be one of the following: aws:updateAgent, aws:domainjoin, aws:applications, aws:runPowerShellScript, aws:psmodule, aws:cloudWatch, aws:runShellScript, or aws:updateSSMAgent.
cpOutputS3BucketName :: Lens' CommandPlugin (Maybe Text) Source #
The S3 bucket where the responses to the command executions should be stored. This was requested when issuing the command.
cpResponseFinishDateTime :: Lens' CommandPlugin (Maybe UTCTime) Source #
The time the plugin stopped executing. Could stop prematurely if, for example, a cancel command was sent.
CreateAssociationBatchRequestEntry
data CreateAssociationBatchRequestEntry Source #
Describes the association of an SSM document and an instance.
See: createAssociationBatchRequestEntry smart constructor.
Instances
createAssociationBatchRequestEntry :: CreateAssociationBatchRequestEntry Source #
Creates a value of CreateAssociationBatchRequestEntry with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
cabreInstanceId :: Lens' CreateAssociationBatchRequestEntry (Maybe Text) Source #
The ID of the instance.
cabreName :: Lens' CreateAssociationBatchRequestEntry (Maybe Text) Source #
The name of the configuration document.
cabreParameters :: Lens' CreateAssociationBatchRequestEntry (HashMap Text [Text]) Source #
A description of the parameters for a document.
DescribeActivationsFilter
data DescribeActivationsFilter Source #
Filter for the DescribeActivation API.
See: describeActivationsFilter smart constructor.
Instances
describeActivationsFilter :: DescribeActivationsFilter Source #
Creates a value of DescribeActivationsFilter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
dafFilterKey :: Lens' DescribeActivationsFilter (Maybe DescribeActivationsFilterKeys) Source #
The name of the filter.
dafFilterValues :: Lens' DescribeActivationsFilter [Text] Source #
The filter values.
DocumentDescription
data DocumentDescription Source #
Describes an SSM document.
See: documentDescription smart constructor.
Instances
documentDescription :: DocumentDescription Source #
Creates a value of DocumentDescription with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
dStatus :: Lens' DocumentDescription (Maybe DocumentStatus) Source #
The status of the SSM document.
dHash :: Lens' DocumentDescription (Maybe Text) Source #
The Sha256 or Sha1 hash created by the system when the document was created.
Sha1 hashes have been deprecated.
dSha1 :: Lens' DocumentDescription (Maybe Text) Source #
The SHA1 hash of the document, which you can use for verification purposes.
dOwner :: Lens' DocumentDescription (Maybe Text) Source #
The AWS user account of the person who created the document.
dPlatformTypes :: Lens' DocumentDescription [PlatformType] Source #
The list of OS platforms compatible with this SSM document.
dCreatedDate :: Lens' DocumentDescription (Maybe UTCTime) Source #
The date when the SSM document was created.
dHashType :: Lens' DocumentDescription (Maybe DocumentHashType) Source #
Sha256 or Sha1.
Sha1 hashes have been deprecated.
dParameters :: Lens' DocumentDescription [DocumentParameter] Source #
A description of the parameters for a document.
dDescription :: Lens' DocumentDescription (Maybe Text) Source #
A description of the document.
DocumentFilter
data DocumentFilter Source #
Describes a filter.
See: documentFilter smart constructor.
Arguments
| :: DocumentFilterKey | |
| -> Text | |
| -> DocumentFilter |
Creates a value of DocumentFilter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
dfKey :: Lens' DocumentFilter DocumentFilterKey Source #
The name of the filter.
DocumentIdentifier
data DocumentIdentifier Source #
Describes the name of an SSM document.
See: documentIdentifier smart constructor.
Instances
documentIdentifier :: DocumentIdentifier Source #
Creates a value of DocumentIdentifier with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
diOwner :: Lens' DocumentIdentifier (Maybe Text) Source #
The AWS user account of the person who created the document.
diPlatformTypes :: Lens' DocumentIdentifier [PlatformType] Source #
The operating system platform.
DocumentParameter
data DocumentParameter Source #
Parameters specified in the SSM document that execute on the server when the command is run.
See: documentParameter smart constructor.
Instances
documentParameter :: DocumentParameter Source #
Creates a value of DocumentParameter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
dpDefaultValue :: Lens' DocumentParameter (Maybe Text) Source #
If specified, the default values for the parameters. Parameters without a default value are required. Parameters with a default value are optional.
dpType :: Lens' DocumentParameter (Maybe DocumentParameterType) Source #
The type of parameter. The type can be either “String” or “StringList”.
dpDescription :: Lens' DocumentParameter (Maybe Text) Source #
A description of what the parameter does, how to use it, the default value, and whether or not the parameter is optional.
FailedCreateAssociation
data FailedCreateAssociation Source #
Describes a failed association.
See: failedCreateAssociation smart constructor.
Instances
failedCreateAssociation :: FailedCreateAssociation Source #
Creates a value of FailedCreateAssociation with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
fcaEntry :: Lens' FailedCreateAssociation (Maybe CreateAssociationBatchRequestEntry) Source #
The association.
fcaMessage :: Lens' FailedCreateAssociation (Maybe Text) Source #
A description of the failure.
InstanceInformation
data InstanceInformation Source #
Describes a filter for a specific list of instances.
See: instanceInformation smart constructor.
Instances
instanceInformation :: InstanceInformation Source #
Creates a value of InstanceInformation with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
iiInstanceId :: Lens' InstanceInformation (Maybe Text) Source #
The instance ID.
iiPingStatus :: Lens' InstanceInformation (Maybe PingStatus) Source #
Connection status of the SSM agent.
iiIPAddress :: Lens' InstanceInformation (Maybe Text) Source #
The IP address of the managed instance.
iiResourceType :: Lens' InstanceInformation (Maybe ResourceType) Source #
The type of instance. Instances are either EC2 instances or managed instances.
iiRegistrationDate :: Lens' InstanceInformation (Maybe UTCTime) Source #
The date the server or VM was registered with AWS as a managed instance.
iiPlatformVersion :: Lens' InstanceInformation (Maybe Text) Source #
The version of the OS platform running on your instance.
iiIsLatestVersion :: Lens' InstanceInformation (Maybe Bool) Source #
Indicates whether latest version of the SSM agent is running on your instance.
iiAgentVersion :: Lens' InstanceInformation (Maybe Text) Source #
The version of the SSM agent running on your Linux instance.
iiLastPingDateTime :: Lens' InstanceInformation (Maybe UTCTime) Source #
The date and time when agent last pinged SSM service.
iiActivationId :: Lens' InstanceInformation (Maybe Text) Source #
The activation ID created by SSM when the server or VM was registered.
iiPlatformType :: Lens' InstanceInformation (Maybe PlatformType) Source #
The operating system platform type.
iiPlatformName :: Lens' InstanceInformation (Maybe Text) Source #
The name of the operating system platform running on your instance.
iiComputerName :: Lens' InstanceInformation (Maybe Text) Source #
The fully qualified host name of the managed instance.
iiIAMRole :: Lens' InstanceInformation (Maybe Text) Source #
The Amazon Identity and Access Management (IAM) role assigned to EC2 instances or managed instances.
InstanceInformationFilter
data InstanceInformationFilter Source #
Describes a filter for a specific list of instances.
See: instanceInformationFilter smart constructor.
Instances
instanceInformationFilter Source #
Arguments
| :: InstanceInformationFilterKey | |
| -> NonEmpty Text | |
| -> InstanceInformationFilter |
Creates a value of InstanceInformationFilter with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
iifKey :: Lens' InstanceInformationFilter InstanceInformationFilterKey Source #
The name of the filter.
iifValueSet :: Lens' InstanceInformationFilter (NonEmpty Text) Source #
The filter values.
NotificationConfig
data NotificationConfig Source #
Configurations for sending notifications.
See: notificationConfig smart constructor.
Instances
notificationConfig :: NotificationConfig Source #
Creates a value of NotificationConfig with the minimum fields required to make a request.
Use one of the following lenses to modify other fields as desired:
ncNotificationEvents :: Lens' NotificationConfig [NotificationEvent] Source #
The different events for which you can receive notifications. These events include the following: All (events), InProgress, Success, TimedOut, Cancelled, Failed. To learn more about these events, see Monitoring Commands in the Amazon Elastic Compute Cloud User Guide .
ncNotificationType :: Lens' NotificationConfig (Maybe NotificationType) Source #
Command: Receive notification when the status of a command changes. Invocation: For commands sent to multiple instances, receive notification on a per-instance basis when the status of a command changes.
ncNotificationARN :: Lens' NotificationConfig (Maybe Text) Source #
An Amazon Resource Name (ARN) for a Simple Notification Service (SNS) topic. SSM pushes notifications about command status changes to this topic.
Tag
Metadata that you assign to your managed instances. Tags enable you to categorize your managed instances in different ways, for example, by purpose, owner, or environment.
See: tag smart constructor.